@@ -1,6 +1,5 @@
 import sys
 from bomiot import version
-from bomiot.server.core.utils import str2bool, str2str, str2json, str2body
 import argparse
 
 optional_title = 'Optional arguments'
@@ -66,6 +65,12 @@ parser.add_argument('-h', '--help', action='help',
 subparsers = parser.add_subparsers(
     dest='command', title='Available commands', metavar='')
 
+# new
+parser_project = subparsers.add_parser(
+    'new', help='Create APP for project')
+parser_project.add_argument('folder', default='',
+                         nargs='?', type=str, help='Create APP')
+
 # project
 parser_project = subparsers.add_parser(
     'project', help='project workspace, default to bomiot')
@@ -78,33 +83,29 @@ parser_plugins = subparsers.add_parser(
 parser_plugins.add_argument('folder', default='',
                          nargs='?', type=str, help='plugins workspace folder')
 
+# deploy
+parser_deploy = subparsers.add_parser(
+    'deploy', help='deploy project')
+parser_deploy.add_argument('folder', default='',
+                         nargs='?', type=str, help='deploy project')
+
+# init
+parser_init = subparsers.add_parser(
+    'init', help='Init bomiot')
+parser_init.add_argument('folder', default='',
+                         nargs='?', type=str, help='Init Bomiot')
 
 # init admin
 parser_initadmin = subparsers.add_parser(
     'initadmin', help='Create default super user admin')
 
-# runserver
-parser_runserver = subparsers.add_parser(
-    'runserver', help='Start Bomiot server')
-parser_runserver.add_argument(
-    'bind', default='127.0.0.1:8008', nargs='?', type=str, help='Host and port to bind')
-
 # migrate
 parser_migrate = subparsers.add_parser('migrate', help='Migrate database')
 
-# create superuser
-parser_createsuperuser = subparsers.add_parser(
-    'createsuperuser', help='Create a custom superuser')
-
 # makemigrations
 parser_makemigrations = subparsers.add_parser(
     'makemigrations', help='Generate migrations for database')
 
-# generate
-parser_generate = subparsers.add_parser(
-    'generate', help='Generate Scrapy code for configurable project')
-parser_generate.add_argument('project', type=str, help='Project to generate')
-
 # loaddata
 parser_loaddata = subparsers.add_parser(
     'loaddata', help='Load data from configs')
@@ -137,10 +138,22 @@ def cmd():
     elif command == 'plugins':
         from bomiot.cmd.plugins import plugins
         plugins(args.folder)
+    # deploy project
+    elif command == 'deploy':
+        from bomiot.cmd.deploy import deploy
+        deploy(args.folder)
+    # init bomiot
+    elif command == 'init':
+        from bomiot.cmd.init import create_file
+        create_file(args.folder)
     # init admin
     elif command == 'initadmin':
-        from bomiot.cmd.initadmin import initadmin
-        initadmin()
+        from bomiot.cmd.initadmin import init_admin
+        init_admin()
+    # create app
+    elif command == 'new':
+        from bomiot.cmd.createapp import new_app
+        new_app(args.folder)
     else:
         from bomiot.server.manage import manage
         manage()
