@@ -4,22 +4,21 @@ from django.contrib.auth import get_user_model
 
 User = get_user_model()
 
-class AsyncAuthentication(object):
-    async def authenticate(self, request) -> tuple[User, bool]:
-        if request.path in ['/docs/', '/swagger/']:
-            return (False, False)
+class CoreAuthentication(object):
+    def authenticate(self, request) -> tuple[User, bool]:
+        if request.path in ['/', '/api/docs/', '/api/debug/', '/api/']:
+            return (False, None)
         else:
             token = request.META.get('HTTP_TOKEN', '')
             result = parse_payload(token)
             if token:
-                user_data = await User.objects.filter(id=result.get('data').aget('id'))
-                if user_data.exists():
-                    user = user_data.afirst()
-                    return (user, True)
-                else:
+                try:
+                    user_data = User.objects.get(id=result.get('data', '').get('id', ''))
+                    return (True, user_data)
+                except:
                     raise APIException({"msg": "User Does Not Exists"})
             else:
                 raise APIException({"msg": "Please Add Token To Your Request Headers"})
 
-    async def authenticate_header(self, request):
+    def authenticate_header(self, request):
         pass
